@@ -2,8 +2,8 @@ import sys
 
 # sys.path.append("../vrpy/")
 sys.path.append("../")
-from vrpy.main import VehicleRoutingProblem
-from vrpy.schedule import Schedule
+from vrpy import VehicleRoutingProblem
+from vrpy.schedule import _Schedule
 
 import logging
 
@@ -36,15 +36,15 @@ if __name__ == "__main__":
 
     prob = VehicleRoutingProblem(
         G,
-        # num_stops=3,
+        num_stops=2,
         # load_capacity=10,
-        duration=39,
+        # duration=39,
         # time_windows=True,
         # distribution_collection=True,
         # fixed_cost=[10, 0],
         # drop_penalty=100,
-        # periodic=2,
-        num_vehicles=3,
+        periodic=2,
+        num_vehicles=1,
         # mixed_fleet=True,
         # minimize_global_span=True,
     )
@@ -54,7 +54,7 @@ if __name__ == "__main__":
         # pricing_strategy="Stops"
         # preassignments=[[2, 3]],
         # time_limit=2,
-        max_iter=10
+        # max_iter=10
     )
     print("routes", prob.best_routes)
     print("cost", prob.best_routes_cost)
