@@ -36,8 +36,8 @@ G = relabel_nodes(G, {0: "Source", 17: "Sink"})
 
 if __name__ == "__main__":
 
-    prob = VehicleRoutingProblem(G, time_windows=True, load_capacity=20)
-    prob.solve(cspy=False)
+    prob = VehicleRoutingProblem(G, time_windows=True)
+    prob.solve()
     print(prob.best_value)
     print(prob.best_routes)
     print(prob.arrival_time)
