@@ -3,7 +3,7 @@
 import logging
 
 from numpy.random import RandomState
-from networkx import DiGraph, NetworkXError, has_path
+from networkx import DiGraph, NetworkXError, has_path, shortest_path_length
 
 logger = logging.getLogger(__name__)
 
@@ -18,6 +18,7 @@ def check_arguments(
     G: DiGraph = None,
     vehicle_types: int = None,
     num_vehicles: list = None,
+    use_all_vehicles: bool = None,
 ):
     """Checks if arguments are consistent."""
 
@@ -59,6 +60,24 @@ def check_arguments(
                     "Cost attribute for edge (%s,%s) has dimension %s, should have dimension %s."
                     % (i, j, len(G.edges[i, j]["cost"]), vehicle_types)
                 )
+    if use_all_vehicles:
+        if not num_vehicles:
+            logger.warning("num_vehicles = None, use_all_vehicles ignored")
+
+
+def check_clarke_wright_compatibility(
+    time_windows, pickup_delivery, distribution_collection, mixed_fleet, periodic
+):
+    if (
+        time_windows
+        or pickup_delivery
+        or distribution_collection
+        or mixed_fleet
+        or periodic
+    ):
+        raise ValueError(
+            "Clarke & Wright heuristic not compatible with time windows, pickup and delivery, simultaneous distribution and collection, mixed fleet, frequencies."
+        )
 
 
 def check_vrp(G: DiGraph = None):
@@ -129,6 +148,23 @@ def check_initial_routes(initial_routes: list = None, G: DiGraph = None):
                 raise KeyError("Edge (%s,%s) has no cost attribute." % (i, j))
 
 
+def check_preassignments(routes: list = None, G: DiGraph = None):
+    """
+    Checks if locked routes are consistent.
+
+    Args:
+        routes (list, optional): Locked routes. Defaults to None.
+        G (DiGraph, optional): Network. Defaults to None.
+    """
+    for route in routes:
+        edges = [(route[k], route[k + 1]) for k in range(len(route) - 1)]
+        for (i, j) in edges:
+            if (i, j) not in G.edges():
+                raise ValueError(
+                    "Edge (%s,%s) in locked route %s is not in graph G." % (i, j, route)
+                )
+
+
 def check_consistency(
     cspy: bool = None,
     pickup_delivery: bool = None,
@@ -166,15 +202,16 @@ def check_feasibility(
     if duration:
         for v in G.nodes():
             if v not in ["Source", "Sink"]:
-                round_trip_duration = (
-                    G.nodes[v]["service_time"]
-                    + G.edges["Source", v]["time"]
-                    + G.edges[v, "Sink"]["time"]
+                shortest_path_to = shortest_path_length(
+                    G, source="Source", target=v, weight="time"
                 )
-                if round_trip_duration > duration:
+                shortest_path_from = shortest_path_length(
+                    G, source=v, target="Sink", weight="time"
+                )
+                shortest_trip = shortest_path_from + shortest_path_to
+                if shortest_trip > duration:
                     raise ValueError(
-                        "Node %s not reachable: duration of path [Source,%s,Sink], %s, is larger than max duration %s."
-                        % (v, v, round_trip_duration, duration)
+                        "Node %s not reachable with duration constraints" % v
                     )
 
 
