@@ -46,6 +46,7 @@ class _MasterSolvePulp(_MasterProblemBase):
         logger.debug("master problem relax %s" % relax)
         logger.debug("Status: %s" % pulp.LpStatus[self.prob.status])
         logger.debug("Objective: %s" % pulp.value(self.prob.objective))
+        # self.prob.writeLP("master.lp")
 
         if pulp.LpStatus[self.prob.status] != "Optimal":
             raise Exception("problem " + str(pulp.LpStatus[self.prob.status]))
@@ -167,16 +168,33 @@ class _MasterSolvePulp(_MasterProblemBase):
 
     def _solve(self, relax: bool, time_limit: Optional[int]):
         # Set variable types
-        for var in self.prob.variables():
-            if relax:
-                var.cat = pulp.LpContinuous
-            else:
+        if not relax:
+            # Set partitioning constraints and artificial variables to integer
+            # (for the periodic case)
+            for node in self.G.nodes():
+                if (
+                    node not in ["Source", "Sink"]
+                    and "depot_from" not in self.G.nodes[node]
+                    and "depot_to" not in self.G.nodes[node]
+                ):
+                    for const in self.prob.constraints:
+                        # Modify the self.prob object (the self.set_covering_constrs object cannot be modified (?))
+                        if "visit_node" in const:
+                            self.prob.constraints[const].sense = pulp.LpConstraintEQ
+                if (
+                    self.periodic
+                    and self.G.nodes[node]["frequency"] > 1
+                    and node != "Source"
+                ):
+                    self.dummy[node].cat = pulp.LpInteger
+            # Set route variables to integer
+            for var in self.y.values():
                 var.cat = pulp.LpInteger
-                # Force vehicle bound artificial variable to 0
+            # Force vehicle bound artificial variable to 0
+            for var in self.dummy_bound.values():
                 if "artificial_bound_" in var.name:
                     var.upBound = 0
                     var.lowBound = 0
-        self.prob.writeLP("master.lp")
         # Solve with appropriate solver
         if self.solver == "cbc":
             self.prob.solve(
@@ -191,7 +209,8 @@ class _MasterSolvePulp(_MasterProblemBase):
                 pulp.CPLEX_CMD(
                     msg=False,
                     timeLimit=time_limit,
-                    options=["set lpmethod 4", "set barrier crossover -1"],
+                    # options=["set lpmethod 4", "set barrier crossover -1"], # set barrier crossover -1 is deprecated
+                    options=["set lpmethod 4", "set solutiontype 2"],
                 )
             )
         elif self.solver == "gurobi":
@@ -276,9 +295,11 @@ class _MasterSolvePulp(_MasterProblemBase):
                 right_hand_term = (
                     self.G.nodes[node]["frequency"] if self.periodic else 1
                 )
+                # Set constraint sign (>= or =)
+                sign = pulp.LpConstraintGE  # if self.relax else pulp.LpConstraintEQ
                 # Save set covering constraints
                 self.set_covering_constrs[node] = pulp.LpConstraintVar(
-                    "visit_node_%s" % node, pulp.LpConstraintGE, right_hand_term
+                    "visit_node_%s" % node, sign, right_hand_term
                 )
 
     def _add_route_selection_variable(self, route):
@@ -286,7 +307,7 @@ class _MasterSolvePulp(_MasterProblemBase):
             "y{}".format(route.graph["name"]),
             lowBound=0,
             upBound=1,
-            cat=pulp.LpInteger,
+            cat=pulp.LpContinuous,
             e=(
                 pulp.lpSum(
                     self.set_covering_constrs[r]
@@ -339,7 +360,7 @@ class _MasterSolvePulp(_MasterProblemBase):
         drop[v] takes value 1 if and only if node v is dropped.
         """
         for node in self.G.nodes():
-            if self.G.nodes[node]["demand"] > 0 and node != "Source":
+            if node not in ["Source", "Sink"]:
                 self.drop[node] = pulp.LpVariable(
                     "drop_%s" % node,
                     lowBound=0,
@@ -359,15 +380,16 @@ class _MasterSolvePulp(_MasterProblemBase):
                     "periodic_%s" % node,
                     lowBound=0,
                     upBound=None,
-                    cat=pulp.LpInteger,
+                    cat=pulp.LpContinuous,
                     e=(1e10 * self.objective + self.set_covering_constrs[node]),
                 )
 
     def _add_bound_vehicles(self):
         """Adds empty constraints and sets the right hand side"""
         for k in range(len(self.num_vehicles)):
+            sign = pulp.LpConstraintEQ if self.use_all_vehicles else pulp.LpConstraintLE
             self.vehicle_bound_constrs[k] = pulp.LpConstraintVar(
-                "upper_bound_vehicles_%s" % k, pulp.LpConstraintLE, self.num_vehicles[k]
+                "upper_bound_vehicles_%s" % k, sign, self.num_vehicles[k]
             )
 
     def _add_makespan_variable(self, new_route=None):
