@@ -17,6 +17,8 @@ from vrpy.checks import (
     check_vrp,
     check_pickup_delivery_time_windows,
     check_periodic_num_vehicles,
+    check_clarke_wright_compatibility,
+    check_preassignments,
 )
 from vrpy.preprocessing import get_num_stops_upper_bound
 from vrpy.hyper_heuristic import _HyperHeuristic
@@ -60,6 +62,9 @@ class VehicleRoutingProblem:
         num_vehicles (int, optional):
             Maximum number of vehicles available.
             Defaults to None (in this case num_vehicles is unbounded).
+        use_all_vehicles (bool, optional):
+            True if all vehicles specified by num_vehicles should be used.
+            Defaults to False.
         periodic (int, optional):
             Time span if vertices are to be visited periodically.
             Defaults to None.
@@ -83,6 +88,7 @@ class VehicleRoutingProblem:
         drop_penalty=None,
         fixed_cost=0,
         num_vehicles=None,
+        use_all_vehicles=False,
         periodic=None,
         mixed_fleet=False,
         minimize_global_span=False,
@@ -99,6 +105,7 @@ class VehicleRoutingProblem:
         self.fixed_cost = fixed_cost
         self.num_vehicles = num_vehicles if num_vehicles is not None else []
         self._num_vehicles_schedule = None
+        self.use_all_vehicles = use_all_vehicles
         self.periodic = periodic
         self.mixed_fleet = mixed_fleet
         self.minimize_global_span = minimize_global_span
@@ -153,6 +160,7 @@ class VehicleRoutingProblem:
         greedy=False,
         max_iter=None,
         run_exact=1,
+        heuristic_only=False,
     ):
         """Iteratively generates columns with negative reduced cost and solves as MIP.
 
@@ -204,6 +212,9 @@ class VehicleRoutingProblem:
                 if a pricing strategy is selected, this parameter controls the number of
                 iterations after which the exact algorithm is run.
                 Defaults to 1.
+            heuristic_only (bool, optional):
+                True if Clarke & Wright solution is return without entering column generation loop.
+                Defaults to False.
 
         Returns:
             float: Optimal solution of MIP based on generated columns
@@ -219,6 +230,7 @@ class VehicleRoutingProblem:
         self._greedy = greedy
         self._max_iter = max_iter
         self._run_exact = run_exact
+        self._heuristic_only = heuristic_only
         if self._pricing_strategy == "Hyper":
             self.hyper_heuristic = _HyperHeuristic()
 
@@ -232,9 +244,14 @@ class VehicleRoutingProblem:
             self._format()
         # Pre-processing
         self._pre_solve()
-        # Initialization
-        self._initialize(solver)
-        self._solve(dive, solver)
+        if self._heuristic_only:
+            # return solution found with Clarke & Wright heuristic
+            self._solve_with_clarke_wright()
+        else:
+            # Initialization
+            self._initialize(solver)
+            # Column generation procedure
+            self._solve(dive, solver)
 
     @property
     def best_routes_type(self):
@@ -350,13 +367,15 @@ class VehicleRoutingProblem:
             for j in range(1, len(route)):
                 tail = route[j - 1]
                 head = route[j]
-                arrival[i][head] = max(
-                    arrival[i][tail]
-                    + self._H.nodes[tail]["service_time"]
-                    + self._H.edges[tail, head]["time"],
-                    self._H.nodes[head]["lower"],
+                arrival[i][head] = min(
+                    max(
+                        arrival[i][tail]
+                        + self._H.nodes[tail]["service_time"]
+                        + self._H.edges[tail, head]["time"],
+                        self._H.nodes[head]["lower"],
+                    ),
+                    self._H.nodes[head]["upper"],
                 )
-            del arrival[i]["Source"]
         return arrival
 
     @property
@@ -366,23 +385,19 @@ class VehicleRoutingProblem:
         First key : route id ; second key : node ; value : departure time.
         """
         departure = {}
+        arrival = self.arrival_time  # need arrival times
         if not self.duration and not self.time_windows:
             return departure
         for i in self.best_routes:
             departure[i] = {}
             departure[i]["Source"] = self._H.nodes["Source"]["lower"]
             route = self.best_routes[i]
-            for j in range(1, len(route) - 1):
+            for j in range(1, len(route)):
                 tail = route[j - 1]
                 head = route[j]
-                departure[i][head] = (
-                    max(
-                        departure[i][tail]
-                        + self._H.nodes[tail]["service_time"]
-                        + self._H.edges[tail, head]["time"],
-                        self._H.nodes[head]["lower"],
-                    )
-                    + self._H.nodes[head]["service_time"]
+                departure[i][head] = min(
+                    arrival[i][head] + self._H.nodes[head]["service_time"],
+                    self._H.nodes[head]["upper"],
                 )
         return departure
 
@@ -412,6 +427,7 @@ class VehicleRoutingProblem:
             G=self.G,
             vehicle_types=self._vehicle_types,
             num_vehicles=self.num_vehicles,
+            use_all_vehicles=self.use_all_vehicles,
         )
         # Setup fixed costs
         if self.fixed_cost:
@@ -434,6 +450,7 @@ class VehicleRoutingProblem:
         )
         # Lock preassigned routes
         if self._preassignments:
+            check_preassignments(self._preassignments, self.G)
             self._lock()
         # Remove infeasible arcs
         self._prune_graph()
@@ -444,6 +461,10 @@ class VehicleRoutingProblem:
             )
             self.num_stops = num_stops
             logger.info("new upper bound : max num stops = %s" % num_stops)
+        # Set empty route cost if use_all_vehicles = True
+        if self.use_all_vehicles:
+            n_vehicle_types = len(self.G["Source"]["Sink"]["cost"])
+            self.G["Source"]["Sink"]["cost"] = n_vehicle_types * [1e10]
 
     def _initialize(self, solver):
         """Initialization with feasible solution."""
@@ -462,6 +483,7 @@ class VehicleRoutingProblem:
             self._routes,
             self.drop_penalty,
             self.num_vehicles,
+            self.use_all_vehicles,
             self.periodic,
             self.minimize_global_span,
             solver,
@@ -809,6 +831,32 @@ class VehicleRoutingProblem:
             )
         return subproblem
 
+    def _solve_with_clarke_wright(self):
+        # return Clarke Wright solution
+        check_clarke_wright_compatibility(
+            self.time_windows,
+            self.pickup_delivery,
+            self.distribution_collection,
+            self.mixed_fleet,
+            self.periodic,
+        )
+        alg = _ClarkeWright(
+            self.G,
+            self.load_capacity,
+            self.duration,
+            self.num_stops,
+        )
+        alg.run()
+        self._best_routes = dict(
+            zip([r for r in range(len(alg.best_routes))], alg.best_routes)
+        )
+        self._best_routes_vehicle_type = dict(
+            zip(
+                [r for r in range(len(alg.best_routes))],
+                [0 for r in range(len(alg.best_routes))],
+            )
+        )
+
     # Preprocessing #
 
     def _get_initial_solution(self):
@@ -859,6 +907,9 @@ class VehicleRoutingProblem:
             )
             self._initial_routes += alg.best_routes
 
+            # TO DO: Run heuristics from VeRyPy for the CVRP
+            # if not self.num_stops and not self.duration:
+
         # If pickup and delivery, initial routes are Source-pickup-delivery-Sink
         elif self.pickup_delivery:
             for v in self.G.nodes():
@@ -882,7 +933,7 @@ class VehicleRoutingProblem:
     def _convert_initial_routes_to_digraphs(self):
         """
         Converts list of initial routes to list of Digraphs.
-        By default, initial routes are computed with vehicle type 0 (the first one in the list).
+        By default, initial routes are computed with the first feasible vehicle type.
         """
         self._routes = []
         self._routes_with_node = {}
@@ -895,7 +946,20 @@ class VehicleRoutingProblem:
                 G.add_edge(i, j, cost=edge_cost)
                 total_cost += edge_cost
             G.graph["cost"] = total_cost
-            G.graph["vehicle_type"] = 0
+            if self.load_capacity:
+                for k in range(len(self.load_capacity)):
+                    if (
+                        sum(self.G.nodes[v]["demand"] for v in r)
+                        <= self.load_capacity[k]
+                    ):
+                        G.graph["vehicle_type"] = k
+                        break
+            else:
+                G.graph["vehicle_type"] = 0
+            if "vehicle_type" not in G.graph:
+                raise ValueError(
+                    "Could not find initial feasible solution. Check loading capacities."
+                )
             self._routes.append(G)
             for v in r[1:-1]:
                 if v in self._routes_with_node:
@@ -918,6 +982,7 @@ class VehicleRoutingProblem:
                 self.G.remove_nodes_from(route[1:-1])
             # Otherwise, keep it and set the costs to 0
             else:
+                logger.info("locking partial route %s" % route)
                 for (i, j) in edges:
                     for k in range(self._vehicle_types):
                         self.G.edges[i, j]["cost"][k] = 0
